# { citizens, councilor, accountants, choosers, authors, voters, governments, politicians, rulers, writers, producers, board, family }

## vote delegation { pools }

voters need to commit to being online in proportional voting systems?

penalties for going offline.

emf_gadget.start ({ "voting invidiual": { "amount": 15000, "ve_private": "", "ve_public": "" } })

## maybe voters is always an aggregate

Voters need to wait until the next voter aggregation to join. This makes it easy to calculate the fraction of voting power that a voter has.

# # every 1000 or so voter steps # voters aggregates: [{ kind: "individual", ve_public: amount: 15000, fraction: "3/4" },{ kind: "individual", ve_public: amount: 5000, fraction: "1/4" }] emf_gadget.start ({ "voting delegate": { "private": "", "public": "" } })

## how is list of voters determined?

voters authorize other voters. possibility of individual voters and delegate voters. so start with 1 voter: { "voting ellipse": { "private": "", "public": "" } }

## secure approvals

could be: 1 creator private ellipse for: making proposals generating approver keys 1 voting private ellipse for approving proposals That way if the voting ellipse is stolen, a new one can be generated from the creator ellipse. { "proposal": { "unsigned": {}, "signed": "" }, "signatures": { public key of signatory: { vote: "yes", # # amount of emf that the signatory has # amount: 123473334923, # # the proposal signed with the private voting ellipse # signature: "" } } } relevant: https://en.wikipedia.org/wiki/Merkle_tree